#
# spec file for package python-poetry-dynamic-versioning
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-poetry-dynamic-versioning
Version:        1.8.2
Release:        1.1
Summary:        Plugin for Poetry to enable dynamic versioning based on VCS tags
License:        MIT
Group:          Development/Libraries/Python
URL:            https://github.com/mtkennerly/poetry-dynamic-versioning
Source:         https://files.pythonhosted.org/packages/source/p/poetry-dynamic-versioning/poetry_dynamic_versioning-%{version}.tar.gz
BuildRequires:  %{python_module devel >= 3.7.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core >= 1.2.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Jinja2
Requires:       python-dunamai >= 1.21.0
Requires:       python-tomlkit
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch

%python_subpackages

%description
%{summary}.

%prep
%autosetup -p1 -n poetry_dynamic_versioning-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/poetry-dynamic-versioning
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%prepare_alternative poetry-dynamic-versioning

%{python_compileall}

%post
%python_install_alternative poetry-dynamic-versioning

%postun
%python_uninstall_alternative poetry-dynamic-versioning

%check
#every test reaches out to the internet

%files %{python_files}
%python_alternative %{_bindir}/poetry-dynamic-versioning
%{python_sitelib}/poetry_dynamic_versioning
%{python_sitelib}/poetry_dynamic_versioning-%{version}.dist-info

%changelog
* Sun Mar 30 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.8.2:
  * Possible object has no attribute 'poetry' error in some projects.
* Mon Mar 24 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.8.1:
  * NameError exception with Python 3.7
* Fri Mar 21 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.8.0:
  * The bump config may now be set to a table, which supports an index field
  * commit-length option to set a fixed length for commit hashes
  * {major}, {minor}, and {patch} format placeholders.
  * Compatibility with other plugins (such as poetry-monoranger-plugin)
  * Updated Dunamai to 1.23.0+ for the latest features.
* Thu Jan 23 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.7.1:
  * There was an intermittent ValueError in PEP 621 mode
* Sat Jan 18 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.7.0:
  * The enable command now supports the bypass/override environment variables
    to use a different placeholder version than 0.0.0.
  * The enable command would add "version" to project.dynamic even if it were
    already present.
  * The enable command would set tool.poetry.version to "0.0.0" even if the
    field were already present with a different value.
- update to 1.6.0:
  * CLI: show command to print the version without changing any files.
- update to 1.5.2:
  * The formatting of project.dynamic and tool.poetry.version could be changed
    when triggering the plugin via poetry dynamic-versioning or pip install
    (but not via poetry build or poetry-dynamic-versioning).
- update to 1.5.1:
  * Array formatting was not preserved when changing project.dynamic in
    pyproject.toml.
* Mon Jan  6 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.5.0:
  * CLI: When pyproject.toml contains the project section, the enable command
    will add the required fields for Poetry 2.0.0+.
  * For compatibility with Poetry 2.0.0, adjusted Poetry constraint from ^1.2.0
    to >=1.2.0
  * For compatibility with Poetry 2.0.0, when inserting the dynamic version
    into pyproject.toml with PEP 621 mode activated, the plugin ensures not to
    set project.version and tool.poetry.version at the same time.
  * An UnboundLocalError could happen when pyproject.toml was misconfigured.
* Wed Sep 11 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.4.1:
  * The enable command would fail when the pyproject.toml tables were out of order.
* Sun Jun 30 2024 Dirk Müller <dmueller@suse.com>
- update to 1.4.0:
  * The plugin now supports Poetry's upcoming PEP-621
    functionality.
* Tue May  7 2024 Dirk Müller <dmueller@suse.com>
- update to 1.3.0:
  * `pattern-prefix` option to add a prefix to the version tag
    pattern.
  * `ignore-untracked` option to control the detection of dirty
    state.
  * `from-file` config section to read a version from a file
    instead of the VCS.
  * `POETRY_DYNAMIC_VERSIONING_DEBUG` environment variable for
    some logging.
  * Updated Dunamai to 1.21.0+ for the latest features
* Fri Feb 23 2024 Richard Rahl <rrahl0@proton.me>
- fix runtime dependencies
* Wed Dec 13 2023 Richard Rahl <rrahl0@proton.me>
- initial packaging
